'''Animation class
Copyright (c) Jan Varho 2013
See README.txt for licensing'''

import pygame
from pygame.locals import *
from math import pi

class Anim:
    
    def __init__(self, img = None, count_x = 1, count_y = 1, fps = 1):
        if img:
            rect = img.get_rect()
            h = rect.height // count_y
            w = rect.width // count_x
            self.images = []
            for j in range(count_y):
                self.images += [img.subsurface(Rect(i*w, j*h, w, h))
                                for i in xrange(count_x)]
            self.count = count_x * count_y
            self.fps = fps
    
    def draw(self, disp, x, y, t, angle = None, centered = 1, scale = None):
        ind = (t * self.fps // 60) % self.count
        img = self.images[ind]
        if angle is not None:
            deg = 180 * (-angle - pi / 2) / pi
            if scale is not None:
                img = pygame.transform.rotozoom(img, deg, scale)
            else:
                img = pygame.transform.rotate(img, deg)
        if centered:
            c = img.get_rect().center
            x -= c[0]
            y -= c[1]
        disp.blit(img, (x, y))
    
    def flipped(self):
        f = Anim()
        f.images = [pygame.transform.flip(i, 1, 0) for i in reversed(self.images)]
        f.count = self.count
        f.fps = self.fps
        return f
    
    def rotated(self, ang = 0):
        if ang == 0:
            return self
        r = Anim()
        r.images = [pygame.transform.rotate(i, ang) for i in self.images]
        r.count = self.count
        r.fps = self.fps
        return r

